@@ -20,8 +20,8 @@ source(paste(path,"/shared_functions.R",sep=""))
 test.mach2databel <- function()
 {
     
-    library("RUnit")
-    library("GenABEL")
+#    library("RUnit")
+#    library("GenABEL")
 
     unlink("test*.fv?")
 
@@ -65,6 +65,8 @@ test.mach2databel <- function()
     
     checkNumEq(txtdose,fvdose)
     checkNumEq(txtprob,fvprob)
+	
+	rm(fvdose,fvprob);gc()
     
     unlink("test*.fv?")    
     
